@@ -230,7 +230,7 @@ class DocType(DocItem):
     def locations(self) -> Sequence[DocLocation]:
         """The [code locations][mkdocstrings.handlers.crystal.items.DocLocation] over which the definitions of this type span."""
         return [
-            DocLocation(loc["filename"], loc["line_number"], loc["url"])
+            self.root.update_url(DocLocation(loc["filename"], loc["line_number"], loc["url"]))
             for loc in self.data["locations"]
         ]
 
@@ -269,6 +269,11 @@ class DocAlias(DocType):
         except KeyError:
             return crystal_html.TextWithLinks(self.data["aliased"], ())
 
+    @property
+    def constants(self):
+        # Crystal duplicates constants into aliases, but that's undesirable.
+        return DocMapping(())
+
 
 class DocAnnotation(DocType):
     """A [DocType][mkdocstrings.handlers.crystal.items.DocType] representing a Crystal annotation."""
@@ -285,7 +290,9 @@ class DocConstant(DocItem):
 
     @property
     def abs_id(self):
-        return (self.parent.abs_id + "::" if self.parent else "") + self.rel_id
+        return (
+            self.parent.abs_id + "::" if self.parent and self.parent.parent else ""
+        ) + self.rel_id
 
     @property
     def kind(self) -> str:
@@ -310,22 +317,24 @@ class DocMethod(DocItem):
 
         args = [arg["external_name"] for arg in d["args"]]
         if d.get("splat_index") is not None:
-            args[d["splat_index"]] = "*" + args[d["splat_index"]]
+            args[d["splat_index"]] = "*"
         if d.get("double_splat"):
-            args.append("**" + d["double_splat"]["external_name"])
-        if d.get("block_arg"):
+            args.append("**")
+        if d.get("block_arg") or d.get("yields"):
             args.append("&")
 
-        return self.name + "(" + ",".join(args) + ")"
+        return self.name + ("(" + ",".join(args) + ")" if args else "")
 
     @property
     def abs_id(self):
-        return (self.parent.abs_id if self.parent else "") + self.METHOD_ID_SEP + self.rel_id
+        return (
+            self.parent.abs_id + self.METHOD_ID_SEP if self.parent and self.parent.parent else ""
+        ) + self.rel_id
 
     @property
     def short_name(self):
         """Similar to [rel_id][mkdocstrings.handlers.crystal.items.DocItem.rel_id], but also includes the separator first, e.g. `#bar(x,y)` or `.baz()`"""
-        return self.METHOD_SEP + self.name
+        return (self.METHOD_SEP if self.parent and self.parent.parent else "") + self.name
 
     @property
     def is_abstract(self) -> bool:
@@ -352,15 +361,17 @@ class DocMethod(DocItem):
         try:
             loc = self.data["location"]
         except KeyError:
-            m = re.fullmatch(
-                r".+?/(?:blob|tree)/[^/]+/(.+)#L(\d+)", self.data.get("source_link") or ""
+            loc = None
+            url = self.data.get("source_link")
+            if url:
+                regex = r"(?P<url>.+?/(?:blob|tree)/[^/]+/(?P<filename>.+)#L(?P<line>\d+))"
+                m = re.fullmatch(regex, url)
+                if m:
+                    loc = m.groupdict()
+        if loc:
+            return self.root.update_url(
+                DocLocation(loc["filename"], loc["line_number"], loc["url"])
             )
-            if m:
-                filename, line = m.groups()
-                return DocLocation(filename, line, self.data.get("source_link"))
-        else:
-            if loc:
-                return DocLocation(loc["filename"], loc["line_number"], loc["url"])
 
 
 class DocInstanceMethod(DocMethod):
