@@ -1,4 +1,3 @@
-import collections
 import contextlib
 import xml.etree.ElementTree as etree
 from typing import Optional, TypeVar, Union
@@ -12,7 +11,6 @@ from markupsafe import Markup
 from mkdocstrings.handlers import base
 
 from . import crystal_html
-from .collector import CrystalCollector
 from .items import DocItem, DocPath
 
 T = TypeVar("T")
@@ -21,16 +19,15 @@ T = TypeVar("T")
 class CrystalRenderer(base.BaseRenderer):
     fallback_theme = "material"
 
-    default_config: dict = {
-        "show_source_links": True,
-        "heading_level": 2,
-    }
-
     def render(self, data: DocItem, config: dict) -> str:
-        subconfig = collections.ChainMap(config, self.default_config)
+        subconfig = {
+            "show_source_links": True,
+            "heading_level": 2,
+            **config,
+        }
         template = self.env.get_template(data._TEMPLATE)
 
-        with self._monkeypatch_highlight_functions(default_lang="crystal"):
+        with self._monkeypatch_highlight_function(default_lang="crystal"):
             return template.render(
                 config=subconfig,
                 obj=data,
@@ -38,22 +35,25 @@ class CrystalRenderer(base.BaseRenderer):
                 root=True,
             )
 
+    def get_anchor(self, data: DocItem) -> str:
+        return data.abs_id
+
     def update_env(self, md: Markdown, config: dict) -> None:
-        md = Markdown(extensions=config["mdx"], extension_configs=config["mdx_configs"])
+        super().update_env(md, config)
         self._md = md
 
         self._pymdownx_hl = None
         for ext in md.registeredExtensions:
-            if hasattr(ext, "get_pymdownx_highlighter"):
-                self._pymdownx_hl = ext
+            try:
+                self._pymdownx_hl = ext.get_pymdownx_highlighter()
+            except AttributeError:
+                pass
 
         # Disallow raw HTML.
         del md.preprocessors["html_block"]
         del md.inlinePatterns["html"]
 
-        base.ShiftHeadingsExtension().extendMarkdown(md)
-        base.PrefixIdsExtension().extendMarkdown(md)
-        XrefExtension(self.collector).extendMarkdown(md)
+        md.treeprocessors.register(_RefInsertingTreeprocessor(md), "mkdocstrings_crystal_xref", 12)
 
         self.env.trim_blocks = True
         self.env.lstrip_blocks = True
@@ -88,28 +88,18 @@ class CrystalRenderer(base.BaseRenderer):
 
     def do_convert_markdown(self, text: str, context: DocItem, heading_level: int, html_id: str):
         self._md.treeprocessors["mkdocstrings_crystal_xref"].context = context
-        return base.do_convert_markdown(
-            self._md, text, heading_level=heading_level, html_id=html_id
-        )
+        return super().do_convert_markdown(text, heading_level=heading_level, html_id=html_id)
 
-    def _monkeypatch_highlight_functions(self, default_lang: str):
-        """Changes 'codehilite' and 'pymdownx.highlight' extensions to use this lang by default."""
+    def _monkeypatch_highlight_function(self, default_lang: str):
+        """Changes 'pymdownx.highlight' extension to use this lang by default."""
         # Yes, there really isn't a better way. I'd be glad to be proven wrong.
         if self._pymdownx_hl:
-            old = self._pymdownx_hl.get_pymdownx_highlighter()
-            members = {
-                "highlight": lambda self, src="", language="", *args, **kwargs: old.highlight(
-                    self, src, language or default_lang, *args, **kwargs
-                )
-            }
-            subclass = type("Highlighter", (old,), members)
-            return _monkeypatch(self._pymdownx_hl, "get_pymdownx_highlighter", lambda: subclass)
-        else:
-            old = fenced_code.CodeHilite
-            new = lambda src, *args, lang=None, **kwargs: old(
-                src, *args, lang=lang or default_lang, **kwargs
+            old = self._pymdownx_hl.highlight
+            new = lambda self, src="", language="", *args, **kwargs: old(
+                self, src, language or default_lang, *args, **kwargs
             )
-            return _monkeypatch(fenced_code, "CodeHilite", new)
+            return _monkeypatch(self._pymdownx_hl, "highlight", new)
+        return contextlib.nullcontext()
 
 
 @contextlib.contextmanager
@@ -122,15 +112,6 @@ def _monkeypatch(obj, attr, func):
         setattr(obj, attr, old)
 
 
-class XrefExtension(Extension):
-    def __init__(self, collector: CrystalCollector, **kwargs) -> None:
-        super().__init__(**kwargs)
-        self.collector = collector
-
-    def extendMarkdown(self, md: Markdown) -> None:
-        md.treeprocessors.register(_RefInsertingTreeprocessor(md), "mkdocstrings_crystal_xref", 12)
-
-
 class _RefInsertingTreeprocessor(Treeprocessor):
     context: Optional[DocItem]
 
